# unfolded.map_sdk

Unfolded Map SDK for Jupyter (Python).

Refer to the documentation website for [how to install](https://docs.unfolded.ai/jupyter/cloud-notebooks/jupyter), [API documentation](https://docs.unfolded.ai/map-sdk/api), and [examples](https://docs.unfolded.ai/map-sdk/examples).
